<!-- badges: start -->
[![CRANStatusBadge](http://www.r-pkg.org/badges/version/timeSeries)](https://cran.r-project.org/package=timeSeries)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/timeSeries)](https://www.r-pkg.org/pkg/timeSeries)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/grand-total/timeSeries?color=blue)](https://r-pkg.org/pkg/timeSeries)
<!-- badges: end -->

The R package 'timeSeries' provides a time series class and tools for creation, import,
manipulation, statistical and financial computations on time series.

Package `timeSeries` is part of the Rmetrics suite of R packages and is developed on R-forge at
[timeSeries](https://r-forge.r-project.org/scm/viewvc.php/pkg/timeSeries/?root=rmetrics).
The root of Rmetrics is at [R-forge](https://r-forge.r-project.org/projects/rmetrics).


# Installing timeSeries


Install the [latest stable version](https://cran.r-project.org/package=timeSeries) of
`timeSeries` from CRAN:

    install.packages("timeSeries")


You can install the
[development version](https://r-forge.r-project.org/scm/viewvc.php/pkg/timeSeries/?root=rmetrics)
of `timeSeries` from R-forge:

    install.packages("timeSeries", repos = "http://R-Forge.R-project.org")

To report bugs visit [Rmetrics](https://r-forge.r-project.org/projects/rmetrics/).

# Documentation

You can view the documentation of `timeSeries` at
[timeSeriesDoc](https://geobosh.github.io/timeSeriesDoc/) (an web site produce with pkgdown)
or download the
[reference manual](https://cran.r-project.org/package=timeSeries/timeSeries.pdf)
of the latest release from CRAN. There is also a large
[vignette on plots](https://cran.r-project.org/package=timeSeries/vignettes/timeSeriesPlot.pdf).
